@@ -42,6 +42,7 @@ from . import genpage
 from . import genmedia
 from . import genfile
 from . import mediautils
+from . import theme
 
 
 from lazygal import INSTALL_MODE, INSTALL_PREFIX
@@ -294,7 +295,7 @@ class WebalbumVideoTask(WebalbumMediaTask):
     def get_resized(self, size_name):
         if not self.webvideo:
             if self.webgal.newsizers[genmedia.VIDEO_SIZE_NAME] == 'original'\
-            and self.media.extension == '.webm':
+            and self.media.extension in ('.webm', '.mp4'):
                 # do not transcode webm videos
                 self.webvideo = self.get_original_or_symlink()
             else:
@@ -368,15 +369,22 @@ class WebalbumDir(make.GroupTask):
 
             self.sort_task.add_dependency(media)
 
+            media_task = None
             if media.type == 'image':
                 media_task = WebalbumImageTask(self, media)
             elif media.type == 'video':
-                media_task = WebalbumVideoTask(self, media)
+                if not self.config.get('webgal', 'novideo'):
+                    media_task = WebalbumVideoTask(self, media)
+                else:
+                    logging.warning(_('Video support disabled: ignoring %s.')
+                                    % media.filename)
             else:
                 raise NotImplementedError("Unknown media type '%s'"
                                           % media.type)
-            self.medias.append(media_task)
-            self.add_dependency(media_task)
+
+            if media_task:
+                self.medias.append(media_task)
+                self.add_dependency(media_task)
 
         # Create the directory if it does not exist
         if not os.path.isdir(self.path) and self.has_media_below():
@@ -408,7 +416,20 @@ class WebalbumDir(make.GroupTask):
             self.break_task = None
 
     def __parse_browse_sizes(self, sizes_defs):
-        for size_defs in sizes_defs:
+        fixed_sizes_defs = sizes_defs
+        if isinstance(sizes_defs, dict):
+            # simpler defs
+            fixed_sizes_defs = []
+            first = True
+            for name, defs in sizes_defs.items():
+                fixed_sizes_defs.append({
+                    "name" : name,
+                    "defs" : defs,
+                    "default" : first,
+                })
+                first = False
+
+        for size_defs in fixed_sizes_defs:
             name = py2compat.u(size_defs['name'], locale.getpreferredencoding())
             if name == genmedia.THUMB_SIZE_NAME:
                 raise ValueError(_("Size name '%s' is reserved for internal processing.") % genmedia.THUMB_SIZE_NAME)
@@ -659,8 +680,6 @@ class WebalbumDir(make.GroupTask):
 
     def make(self, force=False):
         super(WebalbumDir, self).make(force)
-        if self.has_media_below(): # otherwise the dir is not created
-            os.utime(self.pindex._path, None) # update stamp mtime
         self.update_build_status()
 
     def media_done(self):
@@ -683,19 +702,18 @@ class SharedFiles(make.FileMakeObject):
         super(SharedFiles, self).__init__(self.path)
 
         self.expected_shared_files = []
-        for shared_file, shared_file_rel_dest in self.album.theme.shared_files:
-            shared_file_dest = os.path.join(self.path, shared_file_rel_dest)
+        for shared in self.album.theme.shared_files:
+            shared_file_dest = os.path.join(self.path, shared['dest'])
 
-            if self.album.theme.tpl_loader.is_known_template_type(shared_file):
-                sf = genpage.SharedFileTemplate(album, shared_file,
+            if self.album.theme.tpl_loader.is_known_template_type(shared['source']):
+                sf = genpage.SharedFileTemplate(album, shared['source'],
                                                 shared_file_dest,
                                                 tpl_vars)
                 if self.album.force_gen_pages:
                     sf.stamp_delete()
-                self.expected_shared_files.append(sf.path)
             else:
-                sf = genfile.SharedFileCopy(shared_file, shared_file_dest)
-                self.expected_shared_files.append(shared_file_dest)
+                sf = genfile.SharedFileCopy(shared['source'], shared_file_dest)
+            self.expected_shared_files.append(sf.path)
 
             self.add_dependency(sf)
 
@@ -807,8 +825,10 @@ class Album(object):
 
         self.__statistics = None
 
-    def set_theme(self, theme=tpl.DEFAULT_THEME):
-        self.theme = tpl.Theme(os.path.join(DATAPATH, 'themes'), theme)
+    def set_theme(self, theme_name=theme.DEFAULT_THEME):
+        self.theme = theme.Theme(os.path.join(DATAPATH, 'themes'), theme_name)
+        self.theme.prepare_tpl_loader(tpl.TplFactory)
+        self.theme.check_shared_files()
 
     def _str_humanize(self, text):
         dash_replaced = text.replace('_', ' ')
@@ -825,7 +845,7 @@ class Album(object):
             for pattern in self.preserves:
                 # Do not delete something the user wants to keep.
                 if fnmatch.fnmatch(tail, pattern):
-                    logging.info('  PRESERVE %s', file_path)
+                    logging.info('  PRESERVE %s', tail)
                     return
             if os.path.isdir(file_path):
                 shutil.rmtree(file_path)
