@@ -327,6 +327,8 @@ class ImageInfoTags(object):
     def get_focal_length(self):
         try:
             flen = self._metadata.get_exif_tag_rational('Exif.Photo.FocalLength')
+            if not flen:
+                raise KeyError
         except KeyError:
             return ''
         else:
@@ -337,7 +339,8 @@ class ImageInfoTags(object):
         except KeyError:
             pass
         else:
-            flen += _(' (35 mm equivalent: %s mm)') % flen35
+            if flen35 != flen:
+                flen += _(' (35 mm equivalent: %s mm)') % flen35
             return flen
 
         try:
@@ -365,7 +368,8 @@ class ImageInfoTags(object):
             except ZeroDivisionError:
                 raise ValueError
 
-            flen += _(' (35 mm equivalent: %s mm)') % lenstr
+            if lenstr != flen:
+                flen += _(' (35 mm equivalent: %s mm)') % lenstr
         except (IndexError, KeyError, ValueError):
             return flen
 
@@ -417,6 +421,20 @@ class ImageInfoTags(object):
 
         return kw
 
+    def get_location(self):
+        loc = self._metadata.get_gps_info()
+        if loc == (0, 0, 0):
+            return None
+        else:
+            return {
+                # https://xkcd.com/2170/
+                'latitude': round(loc.latitude, 4),
+                'latitudeRef': self._metadata['Exif.GPSInfo.GPSLatitudeRef'],
+                'longitude': round(loc.longitude, 4),
+                'longitudeRef': self._metadata['Exif.GPSInfo.GPSLongitudeRef'],
+                'altitude': round(loc.altitude),
+            }
+
     def of_interest(self):
         return { tag: self._metadata[tag]
                  for tag in TAGS_OF_INTEREST if tag in self._metadata }
